@@ -318,6 +318,22 @@ NS_IMETHODIMP nsScriptablePeer::Isplaying(PRBool * _retval)
     return NS_OK;
 }
 
+/* void playlistAppend (in string filename); */
+NS_IMETHODIMP nsScriptablePeer::PlaylistAppend(const char *item)
+{
+    printf("JS playlistAppend issued\n");
+    mPlugin->PlaylistAppend(item);
+    return NS_OK;
+}
+
+/* void playlistClear (PRInt32 *_retval; */
+NS_IMETHODIMP nsScriptablePeer::PlaylistClear(PRBool * _retval)
+{
+    printf("JS playlistClear issued\n");
+    mPlugin->PlaylistClear(_retval);
+    return NS_OK;
+}
+
 
 /* void SetHREF (in string url); */
 NS_IMETHODIMP nsScriptablePeer::SetHREF(const char *url)
