@@ -51,6 +51,7 @@ char *GetMIMEDescription()
     int enable_qt;
     int enable_rm;
     int enable_gmp;
+    int enable_dvx;
     int enable_mp3;
     int enable_midi;
     int enable_pls;
@@ -82,6 +83,7 @@ char *GetMIMEDescription()
     enable_qt = 1;
     enable_rm = 1;
     enable_gmp = 1;
+    enable_dvx = 1;
     enable_midi = 0;
     enable_pls = 0;
     use_custom_mime_types = 0;
@@ -189,6 +191,15 @@ char *GetMIMEDescription()
 			printf("gmp:%i\n", enable_gmp);
 		    continue;
 		}
+		// Divx Media Player
+		if (strncasecmp(buffer, "enable-dvx", 10) == 0) {
+		    snprintf(parse, 1000, "%s", strtok(buffer, "="));
+		    snprintf(parse, 1000, "%s", strtok(NULL, "="));
+		    sscanf(parse, "%i", &enable_dvx);
+		    if (DEBUG)
+			printf("dvx:%i\n", enable_dvx);
+		    continue;
+		}
 		// MP3
 		if (strncasecmp(buffer, "enable-mp3", 10) == 0) {
 		    snprintf(parse, 1000, "%s", strtok(buffer, "="));
@@ -365,12 +376,13 @@ char *GetMIMEDescription()
 	strlcat(MimeTypes,
 		"application/x-nsv-vp3-mp3:nsv:Nullsoft Streaming Video;",
 		sizeof(MimeTypes));
-	// DIVX
+
+	// Soundtracker
 	strlcat(MimeTypes,
-		"video/divx:divx:DivX Media Format;"
-		"video/vnd.divx:divx:DivX Media Format;",
+		"audio/x-mod:mod:Soundtracker;",
 		sizeof(MimeTypes));
-	// Basic
+    
+ 	// Basic
 	strlcat(MimeTypes,
 		"audio/basic:au,snd:Basic Audio File;"
 		"audio/x-basic:au,snd:Basic Audio File;",
@@ -382,14 +394,12 @@ char *GetMIMEDescription()
 		    "audio/midi:mid,midi,kar:MIDI Audio;",
 		    sizeof(MimeTypes));
 	}
-
 	// PLS
 	if (enable_pls) {
 	    strlcat(MimeTypes,
-   		    "audio/x-scpls:pls:Shoutcast Playlist;",
+		    "audio/x-scpls:pls:Shoutcast Playlist;",
 		    sizeof(MimeTypes));
 	}
-
 #endif
 	// Google Video
 #ifdef GMP
@@ -400,6 +410,17 @@ char *GetMIMEDescription()
 	}
 #endif
 
+#ifdef DVX
+       // DIVX
+    	if (enable_dvx) {
+	strlcat(MimeTypes,
+		"video/divx:divx:DivX Media Format;"
+		"video/vnd.divx:divx:DivX Media Format;",
+		sizeof(MimeTypes));
+	}
+#endif    
+    
+    
     }
     ret = strdup(MimeTypes);
     if (DEBUG)
@@ -427,7 +448,7 @@ NPError GetValue(NPPVariable variable, void *value)
 #endif
 
 #ifdef QT
-	*((const char **) value) = "QuickTime Plug-in 6.0";
+	*((const char **) value) = "QuickTime Plug-in 6.0 / 7";
 #endif
 
 #ifdef RM
@@ -438,6 +459,10 @@ NPError GetValue(NPPVariable variable, void *value)
 	*((const char **) value) = "Google VLC multimedia plugin 1.0";
 #endif
 
+#ifdef DVX
+	*((const char **) value) = "DivX Browser Plug-In";
+#endif
+
     }
     if (variable == NPPVpluginDescriptionString) {
 #ifdef GTK2_ENABLED
@@ -590,6 +615,9 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 		if (strncasecmp(parameters->argv[i], "file://", 7) == 0)
 		    fullyQualifyURL(instance, parameters->argv[i],
 				    instance->href);
+		if (strstr(parameters->argv[i], "<") != NULL)
+		    fullyQualifyURL(instance, parameters->argv[i],
+				    instance->href);
 		instance->state = STATE_HAVEURL;
 	    }
 
@@ -802,6 +830,22 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 		    printf("showlogo=%i\n", instance->showlogo);
 	    }
 
+	    if (strncasecmp(parameters->argn[i], "enablecontextmenu", 8) == 0) {
+
+		lowercase(parameters->argv[i]);
+		if (DEBUG)
+		    printf("argv[i]=%s\n", parameters->argv[i]);
+
+		if (strstr(parameters->argv[i], "false")
+		    || strstr(parameters->argv[i], "no")
+		    || strstr(parameters->argv[i], "0")) {
+		    instance->enablecontextmenu = 0;
+		} else {
+		    instance->enablecontextmenu = 1;
+		}
+		if (DEBUG)
+		    printf("enablecontextmenu=%i\n", instance->enablecontextmenu);
+	    }
 
 	    if ((strncasecmp(parameters->argn[i], "controls", 8) == 0)
 		&& (strstr(instance->mimetype, "quicktime") == NULL)) {
@@ -1094,6 +1138,10 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 	    }
 	}
 
+	if (instance->targetplayer == 1 && instance->href == NULL) {
+	    instance->targetplayer = 0;
+	}
+
     } else {
 	if (DEBUG)
 	    printf("New, full mode %i\n", instance->mode);
@@ -1179,7 +1227,7 @@ void LoadConfigFile(nsPluginInstance * instance)
 		    continue;
 		}
 
-	        if (strncasecmp(buffer, "showstatus", 10) == 0) {
+		if (strncasecmp(buffer, "showstatus", 10) == 0) {
 		    snprintf(parse, 1000, "%s", strtok(buffer, "="));
 		    snprintf(parse, 1000, "%s", strtok(NULL, "="));
 		    // crappy reuse of the hidestatus variable
@@ -1188,7 +1236,7 @@ void LoadConfigFile(nsPluginInstance * instance)
 		    if (instance->hidestatus == 0) {
 			instance->hidestatus = 1;
 		    } else {
-		    	instance->hidestatus = 0;
+			instance->hidestatus = 0;
 		    }
 		    continue;
 		}
@@ -1211,7 +1259,7 @@ void LoadConfigFile(nsPluginInstance * instance)
 		    continue;
 		}
 
-	        if (strncasecmp(buffer, "novop", 5) == 0) {
+		if (strncasecmp(buffer, "novop", 5) == 0) {
 		    snprintf(parse, 1000, "%s", strtok(buffer, "="));
 		    snprintf(parse, 1000, "%s", strtok(NULL, "="));
 		    sscanf(parse, "%i", &instance->novop);
