@@ -96,7 +96,8 @@ void Initialize(Display * dpy, Drawable d, nsPluginInstance * instance,
 	bold = XGetAtomName(dpy, GetFontAtom(dpy, fstr, "WEIGHT_NAME"));
 	italic = XGetAtomName(dpy, GetFontAtom(dpy, fstr, "SLANT"));
 	size = GetFontAtom(dpy, fstr, "PIXEL_SIZE");
-
+	XFreeFontInfo(NULL, fstr, 0);
+    
 	sprintf(fontname, "-*-%s-%s-%s-*--%d-*",
 		family, bold, italic, (int) size);
 	instance->font = XCreateFontSet(dpy,
@@ -692,14 +693,14 @@ void stop_callback(GtkWidget * widget, GdkEventExpose * event,
 	    g_idle_add(gtkgui_message, instance);
 	    gtk_widget_hide(GTK_WIDGET(instance->mediaprogress_bar));
 	}
-    	if (instance->showlogo)
-	    	if (GTK_IS_WIDGET(instance->image))
-		    	gtk_widget_show(GTK_WIDGET(instance->image));
-		
-    	if (!instance->hidestatus)
-	    	if (GTK_IS_WIDGET(instance->status))
-		    	gtk_widget_show(GTK_WIDGET(instance->status));
-		
+	if (instance->showlogo)
+	    if (GTK_IS_WIDGET(instance->image))
+		gtk_widget_show(GTK_WIDGET(instance->image));
+
+	if (!instance->hidestatus)
+	    if (GTK_IS_WIDGET(instance->status))
+		gtk_widget_show(GTK_WIDGET(instance->status));
+
 	gdk_flush();
     }
     if (widget != NULL)
@@ -714,7 +715,7 @@ void ff_callback(GtkWidget * widget, GdkEventExpose * event,
 	return;
     if (instance->panel_drawn == 0 && instance->controlsvisible == 1)
 	return;
-    if (instance->controlsvisible == 1) {
+    if (instance->controlsvisible == 1 && instance->mmsstream == 0) {
 	if (instance->panel_height > 16)
 	    instance->panel_height = 16;
 
@@ -765,7 +766,7 @@ void rew_callback(GtkWidget * widget, GdkEventExpose * event,
 	return;
     if (instance->panel_drawn == 0 && instance->controlsvisible == 1)
 	return;
-    if (instance->controlsvisible == 1) {
+    if (instance->controlsvisible == 1 && instance->mmsstream == 0) {
 
 	if (instance->panel_height > 16)
 	    instance->panel_height = 16;
@@ -1057,16 +1058,16 @@ gboolean gtkgui_draw(void *data)
 	    instance->panel_height = 16;
     }
 
-    if (instance->panel_drawn == 0) {
+    if (instance->panel_drawn == 0 && instance->window != 0) {
 	if (instance->mode == NP_FULL)
 	    instance->panel_height = instance->window_height;
 	if (instance->panel_height > 16)
 	    instance->panel_height = 16;
 	if (instance->panel_height <= 0)
 	    if (instance->showcontrols) {
-	    	instance->panel_height = 16;
+		instance->panel_height = 16;
 	    } else {
-	    	instance->panel_height = 0;
+		instance->panel_height = 0;
 	    }
 	if (DEBUG) {
 	    printf("drawing panel\n height = %i panel= %i\n",
@@ -1136,7 +1137,8 @@ gboolean gtkgui_draw(void *data)
 #endif
 	    multiplier = 0;
 	    // rewind
-	    if ((instance->mmsstream == 0 && win_width > 126) || instance->targetplayer == 1) {
+	    if ((instance->mmsstream == 0 && win_width > 126)
+		|| instance->targetplayer == 1) {
 		instance->rew_event_box = gtk_event_box_new();
 		tooltip = gtk_tooltips_new();
 		gtk_tooltips_set_tip(tooltip, instance->rew_event_box,
@@ -1267,7 +1269,8 @@ gboolean gtkgui_draw(void *data)
 		gtk_widget_show(instance->stop_event_box);
 	    }
 	    // fastforward
-	    if ((instance->mmsstream == 0 && win_width > 126) || instance->targetplayer == 1) {
+	    if ((instance->mmsstream == 0 && win_width > 126)
+		|| instance->targetplayer == 1) {
 		instance->ff_event_box = gtk_event_box_new();
 		tooltip = gtk_tooltips_new();
 		gtk_tooltips_set_tip(tooltip, instance->ff_event_box,
@@ -1398,14 +1401,14 @@ gboolean gtkgui_message(void *data)
 	if (GTK_IS_LABEL(instance->status))
 	    gtk_label_set_text(instance->status, instance->lastmessage);	//GTK_LABEL
 
-    if (instance->js_state == JS_STATE_TRANSITIONING) {	
+    if (instance->js_state == JS_STATE_TRANSITIONING) {
 	if (GTK_IS_WIDGET(instance->image) && instance->showlogo)
 	    gtk_widget_show(GTK_WIDGET(instance->image));
-	
+
 	if (GTK_IS_WIDGET(instance->status) && (!(instance->hidestatus)))
 	    gtk_widget_show(GTK_WIDGET(instance->status));
     }
-	
+
     return FALSE;
 }
 
@@ -1435,10 +1438,10 @@ gboolean gtkgui_progress(void *data)
 	}
     }
 
-    if (instance->js_state == JS_STATE_TRANSITIONING) {	
+    if (instance->js_state == JS_STATE_TRANSITIONING) {
 	if (GTK_IS_WIDGET(instance->image) && instance->showlogo)
 	    gtk_widget_show(GTK_WIDGET(instance->image));
-	
+
 	if (GTK_IS_WIDGET(instance->status) && (!(instance->hidestatus)))
 	    gtk_widget_show(GTK_WIDGET(instance->status));
     }
@@ -1459,7 +1462,7 @@ gboolean gtkgui_resize(void *data)
 
     new_width = instance->movie_width;
     new_height = instance->movie_height;
-	
+
     if (DEBUG > 1)
 	printf("in resize method\nNew size is %i x %i\n",
 	       instance->movie_width, instance->movie_height);
@@ -1474,18 +1477,24 @@ gboolean gtkgui_resize(void *data)
 		    if (instance->fullscreen == 0) {
 			if (GTK_IS_CONTAINER(instance->fixed_container)) {
 			    if (GTK_IS_WIDGET(instance->image))
-				gtk_widget_hide(GTK_WIDGET(instance->image));
+				gtk_widget_hide(GTK_WIDGET
+						(instance->image));
 			    if (GTK_IS_WIDGET(instance->status))
-				gtk_widget_hide(GTK_WIDGET(instance->status));
+				gtk_widget_hide(GTK_WIDGET
+						(instance->status));
 			    if (GTK_IS_WIDGET(instance->mediaprogress_bar))
-				gtk_widget_hide(GTK_WIDGET(instance->mediaprogress_bar));
+				gtk_widget_hide(GTK_WIDGET
+						(instance->
+						 mediaprogress_bar));
 			    instance->showtracker = 0;
-			    gtk_fixed_put(GTK_FIXED
-					  (instance->fixed_container),
-					  instance->drawing_area, 0, 0);
+			    if (gtk_widget_get_parent_window(instance->drawing_area) == NULL) { 
+				gtk_fixed_put(GTK_FIXED
+					      (instance->fixed_container),
+					      instance->drawing_area, 0, 0);
+			    }
 			}
 		    }
-		} 
+		}
 
 		if (instance->showcontrols) {
 		    if (instance->movie_width > instance->window_width
@@ -1549,37 +1558,51 @@ gboolean gtkgui_resize(void *data)
 		    gtk_fixed_put(GTK_FIXED(instance->fixed_container),
 				  instance->drawing_area, 0, 0);
 		    if (GTK_IS_WIDGET(instance->image))
-		    	gtk_widget_hide(GTK_WIDGET(instance->image));
+			gtk_widget_hide(GTK_WIDGET(instance->image));
 		    if (GTK_IS_WIDGET(instance->status))
-		    	gtk_widget_hide(GTK_WIDGET(instance->status));
+			gtk_widget_hide(GTK_WIDGET(instance->status));
 		    if (GTK_IS_WIDGET(instance->mediaprogress_bar))
-			gtk_widget_hide(GTK_WIDGET(instance->mediaprogress_bar));
+			gtk_widget_hide(GTK_WIDGET
+					(instance->mediaprogress_bar));
 
 		} else {
-		    gtk_fixed_put(GTK_FIXED
-				  (instance->fixed_container),
-				  instance->drawing_area, 10, 100);
+		    if (gtk_widget_get_parent_window(instance->drawing_area) == NULL) { 
+			gtk_fixed_put(GTK_FIXED
+				      (instance->fixed_container),
+				      instance->drawing_area, 10, 100);
+		    }
 		    if (GTK_IS_WIDGET(instance->image))
 			gtk_widget_show(GTK_WIDGET(instance->image));
 		    if (GTK_IS_WIDGET(instance->status))
-		    	gtk_widget_show(GTK_WIDGET(instance->status));
+			gtk_widget_show(GTK_WIDGET(instance->status));
 		}
 
 	    } else {
-	    	if (instance->targetplayer && instance->showcontrols) {
+		if (instance->targetplayer && instance->showcontrols) {
 		    gtk_widget_set_usize(instance->drawing_area,
 					 instance->movie_width,
-					 instance->movie_height + 16 );
-		
+					 instance->movie_height + 16);
+
 		} else {
 		    if (instance->showcontrols) {
-		    	if (instance->movie_height > (instance->window_height - 16)) {
-				gtk_widget_set_size_request(GTK_WIDGET(instance->drawing_area),instance->movie_width,instance->window_height -16);
+			if (instance->movie_height >
+			    (instance->window_height - 16)) {
+			    gtk_widget_set_usize(GTK_WIDGET
+						 (instance->drawing_area),
+						 instance->movie_width,
+						 instance->window_height -
+						 16);
 			} else {
-				gtk_widget_set_size_request(GTK_WIDGET(instance->drawing_area),instance->movie_width,instance->movie_height);
+			    gtk_widget_set_usize(GTK_WIDGET
+						 (instance->drawing_area),
+						 instance->movie_width,
+						 instance->movie_height);
 			}
 		    } else {
-			gtk_widget_set_size_request(GTK_WIDGET(instance->drawing_area),instance->movie_width,instance->movie_height);
+			gtk_widget_set_usize(GTK_WIDGET
+					     (instance->drawing_area),
+					     instance->movie_width,
+					     instance->movie_height);
 		    }
 
 		}
@@ -1707,7 +1730,7 @@ gboolean gtkgui_drawMediaProgress(void *data)
     nsPluginInstance *instance;
     int hour = 0, min = 0, length_hour = 0, length_min = 0;
     long int seconds, length_seconds;
-    char display[30];
+    char display[35];
 
     if (DEBUG > 1)
 	printf("in drawMediaProgress method\n");
@@ -1753,26 +1776,69 @@ gboolean gtkgui_drawMediaProgress(void *data)
 			    length_seconds =
 				length_seconds - (length_min * 60);
 			}
-			if (hour == 0 && length_hour == 0) {
-			    snprintf(display, 30, "%2i:%02i / %2i:%02i",
-				     min, (int) seconds, length_min,
-				     (int) length_seconds);
+
+			if ((int) (instance->percent * 100) > 0
+			    && (int) (instance->percent * 100) < 99
+			    && instance->mmsstream == 0) {
+
+			    if (hour == 0 && length_hour == 0) {
+				snprintf(display, 30,
+					 _
+					 ("%2i:%02i / %2i:%02i | %2i%% \342\226\274"),
+					 min, (int) seconds, length_min,
+					 (int) length_seconds,
+					 (int) (instance->percent * 100));
+			    } else {
+				snprintf(display, 30,
+					 _
+					 ("%i:%02i:%02i / %i:%02i:%02i | %2i%% \342\226\274"),
+					 hour, min, (int) seconds,
+					 length_hour, length_min,
+					 (int) length_seconds,
+					 (int) (instance->percent * 100));
+			    }
+
 			} else {
-			    snprintf(display, 30,
-				     "%i:%02i:%02i / %i:%02i:%02i", hour,
-				     min, (int) seconds, length_hour,
-				     length_min, (int) length_seconds);
+
+			    if (hour == 0 && length_hour == 0) {
+				snprintf(display, 30,
+					 "%2i:%02i / %2i:%02i", min,
+					 (int) seconds, length_min,
+					 (int) length_seconds);
+			    } else {
+				snprintf(display, 30,
+					 "%i:%02i:%02i / %i:%02i:%02i",
+					 hour, min, (int) seconds,
+					 length_hour, length_min,
+					 (int) length_seconds);
+			    }
+
 			}
 
 			gtk_progress_bar_set_text(instance->
 						  mediaprogress_bar,
 						  display);
 		    } else {
-			if (gtk_progress_bar_get_text
-			    (instance->mediaprogress_bar) != NULL)
-			    gtk_progress_bar_set_text(instance->
-						      mediaprogress_bar,
-						      NULL);
+			if ((int) (instance->percent * 100) > 0
+			    && (int) (instance->percent * 100) < 99
+			    && instance->mmsstream == 0) {
+
+			    snprintf(display, 30, _("%2i%% \342\226\274"),
+				     (int) (instance->percent * 100));
+			    if (gtk_progress_bar_get_text
+				(instance->mediaprogress_bar) != NULL)
+				gtk_progress_bar_set_text(instance->
+							  mediaprogress_bar,
+							  display);
+
+			} else {
+
+			    if (gtk_progress_bar_get_text
+				(instance->mediaprogress_bar) != NULL)
+				gtk_progress_bar_set_text(instance->
+							  mediaprogress_bar,
+							  NULL);
+			}
 		    }
 #endif
 
@@ -1781,8 +1847,7 @@ gboolean gtkgui_drawMediaProgress(void *data)
 				    (instance->mediaprogress_bar));
 		}
 	    } else {
-		gtk_widget_hide(GTK_WIDGET
-				(instance->mediaprogress_bar));
+		gtk_widget_hide(GTK_WIDGET(instance->mediaprogress_bar));
 	    }
 	}
     }
@@ -1887,7 +1952,7 @@ gboolean gtkgui_updatebuttons(void *data)
     }
 
     if (DEBUG)
-        printf("buttons are at %i x %i\n", win_height, win_width);
+	printf("buttons are at %i x %i\n", win_height, win_width);
 
     if (instance->panel_drawn == 1) {
 	height = 16;
@@ -1907,7 +1972,9 @@ gboolean gtkgui_updatebuttons(void *data)
 		}
 	    }
 	} else {
-	    gtk_widget_hide(GTK_WIDGET(instance->rew_event_box));
+	    if (GTK_IS_WIDGET(instance->rew_event_box)) {
+	    	gtk_widget_hide(GTK_WIDGET(instance->rew_event_box));
+	    }
 	}
 	gtk_fixed_move(GTK_FIXED(instance->fixed_container),
 		       GTK_WIDGET(instance->play_event_box),
@@ -1930,7 +1997,9 @@ gboolean gtkgui_updatebuttons(void *data)
 		}
 	    }
 	} else {
-	    gtk_widget_hide(GTK_WIDGET(instance->ff_event_box));
+	    if (GTK_IS_WIDGET(instance->ff_event_box)) {
+	    	gtk_widget_hide(GTK_WIDGET(instance->ff_event_box));
+	    }
 	}
 	gtk_fixed_move(GTK_FIXED(instance->fixed_container),
 		       GTK_WIDGET(instance->mediaprogress_bar),
@@ -2033,18 +2102,81 @@ void menuitem_fullscreen_callback(GtkCheckMenuItem * menuitem,
 
 }
 
-void menuitem_save_callback(GtkMenuItem * menuitem,
-			    nsPluginInstance * instance)
+void store_filename(GtkWidget * widget, nsPluginInstance * instance)
 {
-    char *filename;
-    char newname[1024];
-    char mmsplaylist[1024];
-    FILE *playlist;
+    const gchar *filename;
     FILE *fin, *fout;
     char buffer[1000];
     int count;
     Node *n, *lastplayed;
 
+    if (instance->mInitialized == FALSE)
+	return;
+    pthread_mutex_lock(&(instance->playlist_mutex));
+
+    lastplayed = NULL;
+
+    if (instance->currentnode != NULL) {
+	lastplayed = instance->currentnode;
+    } else {
+	n = instance->list;
+	while (n != NULL) {
+	    if (n->played == 1)
+		lastplayed = n;
+	    n = n->next;
+	}
+    }
+
+    if (DEBUG)
+	printf("lastplayed = %p\n", lastplayed);
+
+    if (lastplayed != NULL) {
+	filename =
+	    gtk_file_selection_get_filename(GTK_FILE_SELECTION
+					    (instance->file_selector));
+	if (DEBUG)
+	    printf("filename = %s\n", filename);
+
+	if (filename) {
+	    if (lastplayed->retrieved == 1) {
+		if (DEBUG) {
+		    printf("lastplayed->fname = %s\n", lastplayed->fname);
+		}
+
+		if (rename(lastplayed->fname, filename) == 0) {
+		    snprintf(lastplayed->fname, 1024, "%s", filename);
+		    lastplayed->remove = 0;
+		} else {
+
+		    // rename failed (probably cross partitions), copy the file
+		    fin = fopen(lastplayed->fname, "rb");
+		    fout = fopen(filename, "wb");
+		    if (fin != NULL && fout != NULL) {
+			while (!feof(fin)) {
+			    count = fread(buffer, 1, 1000, fin);
+			    fwrite(buffer, 1, count, fout);
+			}
+			fclose(fout);
+			fclose(fin);
+		    }
+		}
+	    }
+	}
+    }
+    pthread_mutex_unlock(&(instance->playlist_mutex));
+    gtk_widget_destroy(instance->file_selector);
+    instance->file_selector = NULL;
+}
+
+
+
+void menuitem_save_callback(GtkMenuItem * menuitem,
+			    nsPluginInstance * instance)
+{
+    const gchar *filename;
+    char mmsplaylist[1024];
+    FILE *playlist;
+    Node *n, *lastplayed;
 
     if (instance->mInitialized == FALSE)
 	return;
@@ -2066,28 +2198,57 @@ void menuitem_save_callback(GtkMenuItem * menuitem,
     if (lastplayed != NULL) {
 	filename = getURLFilename(lastplayed->url);
 	if (filename) {
-	    if (lastplayed->retrieved == 1) {
-		snprintf(newname, 1024, "%s/%s",
-			 instance->download_dir, filename);
-		if (rename(lastplayed->fname, newname) == 0) {
-		    snprintf(lastplayed->fname, 1024, "%s/%s",
-			     instance->download_dir, filename);
-		    lastplayed->remove = 0;
-		} else {
-		    // rename failed (probably cross partitions), copy the file
-		    fin = fopen(lastplayed->fname, "rb");
-		    fout = fopen(newname, "wb");
-		    if (fin != NULL && fout != NULL) {
-			while (!feof(fin)) {
-			    count = fread(buffer, 1, 1000, fin);
-			    fwrite(buffer, 1, count, fout);
-			}
-			fclose(fout);
-			fclose(fin);
-		    }
-		}
-	    }
-	    NPN_MemFree(filename);
+	    instance->file_selector =
+		gtk_file_selection_new
+		(_("Save As..."));
+
+	    gtk_file_selection_set_filename(GTK_FILE_SELECTION
+					    (instance->file_selector),
+					    filename);
+#ifdef GTK2_ENABLED
+	    g_signal_connect(GTK_FILE_SELECTION(instance->file_selector)->
+			     ok_button, "clicked",
+			     G_CALLBACK(store_filename), instance);
+
+	    g_signal_connect_swapped(GTK_FILE_SELECTION
+				     (instance->file_selector)->ok_button,
+				     "clicked",
+				     G_CALLBACK(gtk_widget_destroy),
+				     instance->file_selector);
+
+	    g_signal_connect_swapped(GTK_FILE_SELECTION
+				     (instance->file_selector)->
+				     cancel_button, "clicked",
+				     G_CALLBACK(gtk_widget_destroy),
+				     instance->file_selector);
+#endif
+#ifdef GTK1_ENABLED
+	    gtk_signal_connect(GTK_OBJECT
+			       (GTK_FILE_SELECTION
+				(instance->file_selector)->ok_button),
+			       "clicked", GTK_SIGNAL_FUNC(store_filename),
+			       instance);
+
+	    gtk_signal_connect_object(GTK_OBJECT
+				      (GTK_FILE_SELECTION
+				       (instance->file_selector)->
+				       ok_button), "clicked",
+				      GTK_SIGNAL_FUNC(gtk_widget_destroy),
+				      GTK_OBJECT(instance->file_selector));
+
+	    gtk_signal_connect_object(GTK_OBJECT
+				      (GTK_FILE_SELECTION
+				       (instance->file_selector)->
+				       cancel_button), "clicked",
+				      GTK_SIGNAL_FUNC(gtk_widget_destroy),
+				      GTK_OBJECT(instance->file_selector));
+
+
+#endif
+	    /* Display that dialog */
+
+	    gtk_widget_show(instance->file_selector);
+
 	}
 	if (lastplayed->mmsstream) {
 	    snprintf(mmsplaylist, sizeof(mmsplaylist),
@@ -2131,8 +2292,10 @@ void menuitem_copy_callback(GtkMenuItem * menuitem,
     if (lastplayed != NULL) {
 	fullyQualifyURL(instance, lastplayed->url, localurl);
 #ifdef GTK2_ENABLED
-	clipboard = gtk_clipboard_get(GDK_NONE);
-	gtk_clipboard_set_text(clipboard, localurl, strlen(localurl));
+	clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
+	gtk_clipboard_set_text(clipboard, localurl, -1);
+	clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+	gtk_clipboard_set_text(clipboard, localurl, -1);
 #endif
 #ifdef GTK1_ENABLED
 	ge = gtk_entry_new_with_max_length(strlen(localurl));
@@ -2216,6 +2379,9 @@ gint ApplyConfig(GtkWidget * widget, nsPluginInstance * instance)
     instance->enable_gmp =
 	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
 				     (instance->conf_enable_gmp));
+    instance->enable_dvx =
+	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
+				     (instance->conf_enable_dvx));
     instance->enable_mpeg =
 	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
 				     (instance->conf_enable_mpeg));
@@ -2290,6 +2456,7 @@ gint ApplyConfig(GtkWidget * widget, nsPluginInstance * instance)
 	fprintf(output, "enable-qt=%i\n", instance->enable_qt);
 	fprintf(output, "enable-rm=%i\n", instance->enable_rm);
 	fprintf(output, "enable-gmp=%i\n", instance->enable_gmp);
+	fprintf(output, "enable-dvx=%i\n", instance->enable_dvx);
 	fprintf(output, "enable-mpeg=%i\n", instance->enable_mpeg);
 	fprintf(output, "enable-mp3=%i\n", instance->enable_mp3);
 	fprintf(output, "enable-ogg=%i\n", instance->enable_ogg);
@@ -2319,6 +2486,7 @@ gint ApplyConfig(GtkWidget * widget, nsPluginInstance * instance)
 	    } else if (strncasecmp(buffer, "enable-pls", 10) == 0) {
 	    } else if (strncasecmp(buffer, "enable-ogg", 10) == 0) {
 	    } else if (strncasecmp(buffer, "enable-gmp", 10) == 0) {
+	    } else if (strncasecmp(buffer, "enable-dvx", 10) == 0) {
 	    } else if (strncasecmp(buffer, "enable-smil", 11) == 0) {
 	    } else if (strncasecmp(buffer, "enable-helix", 12) == 0) {
 	    } else if (strncasecmp(buffer, "nomediacache", 12) == 0) {
@@ -2367,6 +2535,7 @@ gint ApplyConfig(GtkWidget * widget, nsPluginInstance * instance)
 	    fprintf(output, "enable-qt=%i\n", instance->enable_qt);
 	    fprintf(output, "enable-rm=%i\n", instance->enable_rm);
 	    fprintf(output, "enable-gmp=%i\n", instance->enable_gmp);
+	    fprintf(output, "enable-dvx=%i\n", instance->enable_dvx);
 	    fprintf(output, "enable-mpeg=%i\n", instance->enable_mpeg);
 	    fprintf(output, "enable-mp3=%i\n", instance->enable_mp3);
 	    fprintf(output, "enable-midi=%i\n", instance->enable_midi);
@@ -2396,6 +2565,9 @@ gint ApplyConfig(GtkWidget * widget, nsPluginInstance * instance)
     strlcat(buffer, "/.mozilla/pluginreg.dat", 1000);
     unlink(buffer);
     snprintf(buffer, 1000, "%s", getenv("HOME"));
+    strlcat(buffer, "/.firefox/pluginreg.dat", 1000);
+    unlink(buffer);
+    snprintf(buffer, 1000, "%s", getenv("HOME"));
     strlcat(buffer, "/.mozilla/firefox/pluginreg.dat", 1000);
     unlink(buffer);
     NPN_ReloadPlugins(FALSE);
@@ -2712,6 +2884,17 @@ void menuitem_config_callback(GtkMenuItem * menuitem,
 				 instance->enable_pls);
     gtk_widget_show(instance->conf_enable_pls);
 
+    instance->conf_enable_dvx =
+	gtk_check_button_new_with_label(_("Enable DivX Support"));
+    gtk_table_attach_defaults(GTK_TABLE(conf_table),
+			      instance->conf_enable_dvx, 1, 2, row,
+			      row + 1);
+    row++;
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				 (instance->conf_enable_dvx),
+				 instance->enable_dvx);
+    gtk_widget_show(instance->conf_enable_dvx);
+
     instance->conf_nomediacache =
 	gtk_check_button_new_with_label(_
 					("Play media directly from site (No Caching)"));
@@ -2906,15 +3089,15 @@ int srcToButton(char *url, nsPluginInstance * instance)
 	printf("In srcToButton\n");
 
     // try to load the file natively
-    
+
     instance->pb_src = gdk_pixbuf_new_from_file(url, &error);
-    
+
     if (instance->pb_src == NULL) {
 	// setup tmp directory
 	dirname =
 	    g_strdup_printf("%s", tempnam("/tmp", "mplayerplug-inXXXXXX"));
 	filename = g_strdup_printf("%s/00000001.jpg", dirname);
-    
+
 	// run mplayer and try to get the first frame and convert it to a jpeg
 	command =
 	    g_strdup_printf("mplayer -vo jpeg:outdir=%s -frames 1 %s",
@@ -2923,7 +3106,7 @@ int srcToButton(char *url, nsPluginInstance * instance)
 	    (command, NULL, NULL, &exit_status, &error))
 	    printf("Error when running When running command: %s\n%s\n",
 		   command, error->message);
-    
+
 	if (fexists(filename)) {
 	    error = NULL;
 	    instance->pb_src = gdk_pixbuf_new_from_file(filename, &error);
@@ -2931,7 +3114,7 @@ int srcToButton(char *url, nsPluginInstance * instance)
 	    instance->pb_src =
 		gdk_pixbuf_new_from_xpm_data((const char **) start);
 	}
-    
+
     }
 
     if (instance->pb_src != NULL) {
@@ -2992,11 +3175,17 @@ int srcToButton(char *url, nsPluginInstance * instance)
 	    gtk_widget_show(instance->gtkwidget);
 	result = FALSE;
     }
-    remove(filename);
-    remove(dirname);
 
-    g_free(filename);
-    g_free(dirname);
+    if (filename != NULL) {
+	remove(filename);
+	g_free(filename);
+    }
+
+    if (dirname != NULL) {
+	remove(dirname);
+	g_free(dirname);
+    }
+
     return result;
 
 #endif
